Concepts and terminology — Rucio 1.2 documentation

# Concepts and terminology

The following concepts define how data is organised, accessed, and catalogued by Rucio. Some concepts, such as accounts, data identifiers, or replication rules are fundamental for all types of users, while other concepts, such as notifications or subscriptions, are suitable for more advanced use cases.

- Rucio account
- Files, Datasets and Containers
- Rucio Storage Element
- Meta-data attributes
- Permission model
- Replica management with replication rules
- Replication rule examples
- RSE Expressions
- Accounting and quota
- Notifications
- Subscriptions